  funs_version::"0.04",funs_date::"12.09.1999";

/*            ************  funs  ***********
  This file, funs, contains "load" statements that load esl code.
  It is itself loaded to esl by a load statement. This shows that load
  statements can be nested (actually, they can be nested to arbitrary depths).

  This load of "funs" may be done automatically when esl is started, depending
  on the configuration.

  The load statement is, in its full form, something like

  load("/usr/local/esl/funs");

  If the system variable $allowfunasprefix is set to #t (true, this is the
  default), then you can omit the parentheses, i.e. it suffices to type

  load "/usr/local/esl/funs";

  If, moreover, the system variable $path is set to $system and $systempath
  points to the directory where funs is, then it is even sufficient to type

  load "funs";

  Actually, the load statements in this file assume the path set correctly,
  they have the form

  load("filename");

  It should be possible to reload esl code using the load function without
  problemes.

  There is no namespaces management in esl (yet), i.e. when esl code is
  loaded it is evaluated as if it were typed in interactively, evalution
  takes place in the top level environment.

  Loading an esl file may produce lots of output, depending on the scheme
  system that is the base of esl.

  As you can see, there are two types of comments in esl:

  The first type is similar to C comments (enclosed in /* ... */). Note,
  however, that these comments may be nested, and that "/*" and "*/" within
  strings (i.e. enclosed whithin double quotes) are not recognized as
  comment delimiting symbols.

  The second comment type is an "end of line comment". Three asterisks (***) 
  and everything following these three asterisk up to the end of line is 
  considered a comment. No character within an end of line comment has a
  special meaning (not even backslash).

  Do not take the esl code too seriously. It is not optimized in any way,
  it should mereley be a "proof of a concept". 

  However, I find the plot procedure (ploteps and xploteps in file plot)
  really useful.

*/

/* ****** Procedures concerning function (composition and sum) ****** */
displayln
  ("Trying to load \"help\".");

load("help");

displayln
  ("Trying to load procedures from \"functions\".");

load("functions");

/* ****** Combinatorics procedures ****** */

*** displayln
***  ("Trying to load procedures from \"combinatorics\".");
*** load("combinatorics");
displayln(
 "\"combinatorics\"-procedures not loaded - use \nload(\"combinatorics\");\n");


/* ****** Numerical quadrature procedures ****** */

displayln
  ("Trying to load quadrature procedures from \"quad\".");

load("quad");

/* ****** Miscellanious numerical Computations ****** */

*** displayln
***  ("Trying to load miscellanious numerical procedures from \"misc_num\".");
*** load("misc_num");
displayln("\"misc_num\"-procedures not loaded - use \nload(\"misc_num\");\n");

/* ****** Ordinary differential equations ****** */

*** displayln("Now trying to load",
***               "ordinary differential equations procedures from \"ode\".");
*** load("ode");
displayln("\"ode\"-procedures not loaded - use \nload(\"ode\");\n");

/* ****** Matrices ****** */

displayln
   ("Now trying to load matrix procedures from \"matrices\".");

load("matrices");

/* ****** Linear algebra ****** */

*** displayln
***  ("Now trying to load linear algebra procedures from \"linear_algebra\".");

*** load("linear_algebra");
displayln("\"linear_algebra\"-procedures not loaded - use \n",
"load(\"linear_algebra\");\n");

/* ********** Fourier coefficient procedures ************ */

*** displayln
***  ("Now trying to load fourier coefficients procedures from \"fourier\".");

*** load("fourier");

displayln("\"fourier\"-procedures not loaded - use \nload(\"fourier\");\n");

/* ********** Plot procedures ************ */

displayln
   ("Now trying to load plot procedures from \"plot\".");

load("plot");

/* ********** Procedures for symbolic function manipulations ************ */

displayln
   ("Now trying to load symbolic function procedures from \"symfuns\".");

load("symfuns");

/* ********* System procedures ********** */

displayln
   ("Now trying to load system interface procedures from \"sys_interface\".");

load("sys_interface");

/* ********* plotwords ********** */

displayln
   ("Now trying to load plotwords from \"plotwords\".");

load("plotwords");


displayln("\nModule \"funs\" (Version ",funs_version,", ",funs_date,")");
