                             esl control structures   first version 25.01.2005
                             **********************              

This is a description of the esl control structures. These structures
share a common pattern. They start with a keyword and end with the
concatenation of "end" and the start keyword (e.g. for ... endfor, or
if ... endif). The only exception to this rule is begin ... end (there is no
such thing as "endbegin").
Other keywords may be located between the start and end keyword, as in
for ... from ... to ... do ... end.
Of course, control structures may be nested. 
Control structures may be used for results, or for action, or for both.
Typically, control structures return a value. The use of control structures
for results may be less common.

Example 1:

a:= if x>= 0 then sqrt(x) else sqrt(-x) endif

Here the if control structure is used for result.

In most cases, between the parts of a control structures several statements,
separated by commas, may be used.

Example 2:

while a:=pop(l), numberq(a) do displayln(a," ",a*a) endwhile

The result of the last statement is used for the test (here: numberq(a))

In not too complicated situations, the meaning of the control constructs
should be obvious. Visibility rules, however, are not always simple.
Refer to the scheme language report (Revised 5 report on the algorithmic
language scheme).

The control statements
----------------------

1. if
=====
There are some variants
1.1
  if ... then ... endif
1.2
  if ... then ... else ... endif
1.3
  if ... then ... elseif [ ... elseif] endif
1.4
  if ... then ... elseif [ ... elseif] ... else ... endif

2. while
========
  while ... do ... endwhile

3. repeat
=========

  repeat ... until ... endrepeat

4. for
======

4.1
  for [var] from ... to ... do ... endfor
4.2
  for [var] from ... to ... by ... do ... endfor
4.3
  for [var] in lis do ... endfor

[var] must be a simple variable. In 4.3, lis must be a list (or an expression
that evaluates to a list).  The to values may be less than the from value.
The by value must be positive, if the to value is greater than the from value.
The by value must be negative, if the to value is less than the from value.
The by value may be a floating point number, and it may be less than 0.
In variants 4.1 and 4.2, "for" returns the last value from the last "do"
part. 4.3 can be used only for action (not for value).


5. case
=======

case ... of test, ... of test, ... [of test, ...] else ... endcase

6. with
=======

This is not Pascal's "with", but schemes "let" (or "let*").
It is used to introduce something like a block with new variable bindings.

with a:: [expr], b::[expr] , .. do ... endwith

Example:

with a:: x*x, b::a+x do displayln(a,b) endwith

7. begin
========

begin ... end

is a simple compound statement. begin ... end should be used for the
definition of functions whose body consist of more than one statement:
f(x) :: begin [statemant 1], [statement 2], ... end
Otherwise, begin ... end is not very importand, because control
structure establish implicit compounds. 
The value of begin ... end is the value of the last statment before "end".
begin ... end may be used to reduce the amount of output.
