matrices_version::"0.02", matrices_date::"30.09.1999";

matrixq(a):: 
if arrayq(a) and arraydim(a)=2 then  *** returns the matrix description, if a
  rest(arrayq(a))                    *** is a matrix (i.e. a 2-dimensional
else                                 *** array), else returns #f 
  #f
endif;

zerorow(n)::                             *** row of numbers zero
if not integerq(n) or n<1 then
  displayln("zerovector: invalid argument",n),
  0
else
  with zr::[1..1,1..n] do
      for j from 1 to n do
        zr[1,j]:=0
      endfor,
      zr
  endwith
endif;

makerow(l)::
if not list(l) or length(l)=0 then
  displayln("makerow: argument must be list of length at least 1."),
  0
else
  with zr::[1..1,1..length(l)] do
    for j from 1 to length(l) do 
       zr[1,j]:=listref(l,j-1)
    endfor,
    zr
  endwith
endif;

makevector(l)::
if not list(l) or length(l)=0 then
  displayln("makevector: argument must be list of length at least 1."),
  0
else
  with vec::[1..length(l)] do
    for j from 1 to length(l) do vec[j]:=listref(l,j-1) endfor,
    vec
  endwith
endif;

vec2col(l)::
if not (arrayq(l) and arraydim(l) = 1 and lowindex(l,1) = 1) then
  displayln
   ("vec2col: argument must be an array of dim 1 and low index 1."),
  #f
else
  with n::highindex(l,1), col::[1..n,1..1] do
    for i from 1 to n do col[i,1] := l[i] endfor,
    col
  endwith
endif;

col2vec(l)::
if not (   matrixq(l) 
       and lowindex(l,1)  = 1 
       and lowindex(l,2)  = 1
       and highindex(l,2) = 1) then
  displayln
   ("col2vec: argument must be a column matrix."),
  #f
else
  with n::highindex(l,1), vec::[1..n] do
    for i from 1 to n do vec[i] := l[i,1] endfor,
    vec
  endwith
endif;

checklistoflists(l)::
if not list(l) or length(l)=0 then
  displayln("checklistoflists: argument must be list of length at least 1."),
  #f
elseif not list(first(l)) or length(first(l))=0 then
  displayln("checklistoflists: Each element of the argument must be a list",
                                                 "of length at least 1."),
  #f
else  
  with 
    n::length(l),
    m::length(first(l)),
    ismatrix::#t,
    line::l
  do
    while not nullq(line) and ismatrix do
      ismatrix : (length(first(l)) = m),
      line : rest(line)
    endwhile,
    if ismatrix then
      list(n,m)
    else
      #f
    endif
  endwith
endif;

makematrix(l)::
if not checklistoflists(l) then
  displayln("makematrix: argument must be list of length at least 1,",
            "elements of this list\n",
            "must be lists, all of the same length of at least 1."),
  #f
else
  with 
    n :: length(l),
    m :: length(first(l)),
    mat :: [1..n,1..m]
  do
    for i from 1 to n do
      for j from 1 to m do mat[i,j] := listref(listref(l,i-1),j-1) endfor
    endfor,
    mat
  endwith
endif;

makecol(l)::
if not list(l) or length(l)=0 then
  displayln("makecol: argument must be list of length at least 1."),
  0
else
  with zc::[1..length(l),1..1] do
    for j from 1 to length(l) do 
       zc[j,1] := listref(l,j-1)
    endfor,
    zc
  endwith
endif;

zerocol(n)::                             *** column of numbers zero
if not integerq(n) or n<1 then
  displayln("zerovector: invalid argument",n),
  0
else
  with zc::[1..n,1..1] do
      for j from 1 to n do
        zc[j,1] := 0
      endfor,
      zc
  endwith
endif;

matcopy(a)::           *** returns a newly allocated matrix which is a
                       *** copy of the matrix a.

if not matrixq(a) then
  displayln("matcopy: a is not a matrix"),
  {}
else
  with
    rl::lowindex(a,1),ru::highindex(a,1),
    cl::lowindex(a,2),cu::highindex(a,2),
    s::[rl..ru,cl..cu]
  do
    for r from rl to ru do
      for c from cl to cu do
        s[r,c] := a[r,c]
      endfor
    endfor,
    first(restofrest(s)) := third(a),  *** setzt die Indexfunktion von a in s
    s                                  *** ein. Die automatisch mit erzeugte
  endwith                              *** Indexfunktion wird nicht als 
endif;                                 *** "equal" erkannt.
                                      
 
matdisplay(a)::                        *** displays the matrix a
if not matrixq(a) then
  displayln("matdisplay: argument is not a matrix"),
  {}
else
  displayln("The matrix has lines from ",
            lowindex(a,1)," to ",highindex(a,1),
            " and columns from ",lowindex(a,2)," to ",highindex(a,2),"."),
  for i from lowindex(a,1) to highindex(a,1) do
    display("line",if i<10 then " " else "" endif,i,":  "),
    for j from lowindex(a,2) to highindex(a,2) do display(a[i,j]," ") endfor,
    displayln()
  endfor,
  {}
endif;


displayln("\nModule \"matrices\" (Version ",matrices_version,", ",
                                     matrices_date,")");
